Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(120)

Unified Diff: scripts/slave/recipe_modules/chromium/config.py

Issue 1241643002: V8 Buildbot: Disable lsan on bots where it's not supported. (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/tools/build
Patch Set: Moar expectations Created 5 years, 5 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « no previous file | scripts/slave/recipes/libyuv/libyuv.expected/client_libyuv_mac_asan.json » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: scripts/slave/recipe_modules/chromium/config.py
diff --git a/scripts/slave/recipe_modules/chromium/config.py b/scripts/slave/recipe_modules/chromium/config.py
index 73113c331dd58ca7374f4734f18209fbb45e1e8c..9e23380d84a4ebb80774e354c41abf22f4465570 100644
--- a/scripts/slave/recipe_modules/chromium/config.py
+++ b/scripts/slave/recipe_modules/chromium/config.py
@@ -393,8 +393,8 @@ def asan(c):
fastbuild(c, invert=True, optional=False)
c.gyp_env.GYP_DEFINES['asan'] = 1
- if c.TARGET_PLATFORM != 'android':
- # LSAN isn't supported on Android.
+ if c.TARGET_PLATFORM != 'android' and c.TARGET_BITS == 64:
+ # LSAN isn't supported on Android or 32 bits platforms.
c.gyp_env.GYP_DEFINES['lsan'] = 1
@config_ctx(deps=['compiler'])
@@ -517,8 +517,6 @@ def chromium_win_clang_official(c):
@config_ctx(includes=['chromium_win_clang', 'asan', 'static_library'])
def chromium_win_clang_asan(c):
Michael Achenbach 2015/07/15 07:16:37 This is now covered by excluding 32 bits above.
- # Clear lsan configuration for win.
- del c.gyp_env.GYP_DEFINES['lsan']
# These are set on the lkgr bot, and the fyi bots should match the lkgr bot.
# TODO(thakis): Once the lkgr bot uses recipes, the lkgr and the fyi bots
# should use the same context to ensure they use the same gyp defines.
« no previous file with comments | « no previous file | scripts/slave/recipes/libyuv/libyuv.expected/client_libyuv_mac_asan.json » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698